@@ -13,7 +13,7 @@ def parse(hub, param: "botocore.model.Shape", required: bool):
         "default": None,
         "target_type": "mapping",
         "target": "kwargs",
-        "param_type": hub.pop_create.aws.plugin.type(param.type_name),
+        "param_type": hub.pop_create.aws.param.type(param.type_name),
         "doc": "\n            ".join(
             hub.tool.format.wrap.wrap(
                 docstring,
