@@ -33,31 +33,46 @@ CREATE_FUNCTIONS = (
 
 NAME_PARAMETER = {
     "default": None,
-    "doc": "A name, ID to identify the resource",
+    "doc": "An Idem name of the resource",
     "param_type": "Text",
     "required": True,
     "target": "hardcoded",
     "target_type": "arg",
 }
 
+RESOURCE_ID_PARAMETER = {
+    "default": None,
+    "doc": "An identifier of the resource in the provider",
+    "param_type": "Text",
+    "required": False,
+    "target": "hardcoded",
+    "target_type": "arg",
+}
 
 PRESENT_REQUEST_FORMAT = r"""
-    result = dict(comment="", old_state=None, new_state=None, name=name, result=True)
-    {{ function.hardcoded.resource_function_call }}
-    before = {{ function.hardcoded.describe_function_call }}
-    if ctx.get("test", False):
-        if before:
-            result["comment"] = f"Would update aws.{{ function.hardcoded.service_name }}.{{ function.hardcoded.resource }} {name}"
-            result["result"] = True
-        else:
-            result["comment"] = f"Would create aws.{{ function.hardcoded.service_name }}.{{ function.hardcoded.resource }} {name}"
-            result["result"] = True
-        return result
-
+    # TODO: result["old_state"] and result["new_state"] should be populated with the same parameters as the present() input parameters.
+    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
+    before = None
+    resource_updated = False
+    if resource_id:
+        {{ function.hardcoded.resource_function_call }}
+        before = {{ function.hardcoded.describe_function_call }}
     if before:
-        result["comment"] = f"'{name}' already exists"
         # TODO perform day-2 modifications as needed here
+        # TODO if ctx.test is True, no update call should be made to AWS, but parameter values should still be compared
+        # and the "new_state" return should reflect the updated value that would be made if actual update calls happened.
+        resource_updated = True
+        if ctx.get("test", False) and resource_updated:
+            # TODO populate result["new_state"]
+            result["comment"] = (f"Would update aws.{{ function.hardcoded.service_name }}.{{ function.hardcoded.resource }} '{name}'",)
+            return result
+        if not resource_updated:
+            result["comment"] = (f"'{name}' already exists",)
     else:
+        if ctx.get("test", False):
+            # TODO populate result["new_state"]
+            result["comment"] = (f"Would create aws.{{ function.hardcoded.service_name }}.{{ function.hardcoded.resource }} {name}",)
+            return result
         try:
             ret = await {{ function.hardcoded.create_function }}(
                 ctx,
@@ -68,9 +83,9 @@ PRESENT_REQUEST_FORMAT = r"""
             if not result["result"]:
                 result["comment"] = ret["comment"]
                 return result
-            result["comment"] = f"Created '{name}'"
+            result["comment"] = (f"Created '{name}'",)
         except hub.tool.boto3.exception.ClientError as e:
-            result["comment"] = f"{e.__class__.__name__}: {e}"
+            result["comment"] = result["comment"] + (f"{e.__class__.__name__}: {e}",)
             result["result"] = False
 
     {{ function.hardcoded.waiter_call }}
@@ -78,25 +93,33 @@ PRESENT_REQUEST_FORMAT = r"""
     ...
 
     try:
-        after = {{ function.hardcoded.describe_function_call }}
-        result["new_state"] = after
+        if ctx.get("test", False):
+            # TODO populate result["new_state"]
+            ...
+        elif (not before) or resource_updated:
+            after = {{ function.hardcoded.describe_function_call }}
+            result["new_state"] = after
+        else:
+            result["new_state"] = copy.deepcopy(result["old_state"])
     except Exception as e:
-        result["comment"] = str(e)
+        result["comment"] = result["comment"] + (str(e),)
         result["result"] = False
     return result
 """
 
 ABSENT_REQUEST_FORMAT = r"""
-    result = dict(comment="", old_state=None, new_state=None, name=name, result=True)
+    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     {{ function.hardcoded.resource_function_call }}
     before = {{ function.hardcoded.describe_function_call }}
 
     if not before:
-        result["comment"] = f"'{name}' already absent"
+        result["comment"] = (f"'{name}' already absent",)
     elif ctx.get("test", False):
-        result["comment"] = f"Would delete aws.{{ function.hardcoded.service_name }}.{{ function.hardcoded.resource }} {name}"
+        # TODO populate result["new_state"]
+        result["comment"] = (f"Would delete aws.{{ function.hardcoded.service_name }}.{{ function.hardcoded.resource }} '{name}'",)
         return result
     else:
+        # TODO populate result["old_state"]
         result["old_state"] = before
         try:
             ret = await {{ function.hardcoded.delete_function }}(
@@ -109,18 +132,12 @@ ABSENT_REQUEST_FORMAT = r"""
                 result["comment"] = ret["comment"]
                 result["result"] = False
                 return result
-            result["comment"] = f"Deleted '{name}'"
+            result["comment"] = (f"Deleted '{name}'",)
         except hub.tool.boto3.exception.ClientError as e:
-            result["comment"] = f"{e.__class__.__name__}: {e}"
+            result["comment"] = result["comment"] + (f"{e.__class__.__name__}: {e}",)
 
     {{ function.hardcoded.waiter_call }}
 
-    try:
-        after = {{ function.hardcoded.describe_function_call }}
-        result["new_state"] = after
-    except Exception as e:
-        result["comment"] = str(e)
-        result["result"] = False
     return result
 """
 
@@ -132,6 +149,7 @@ DESCRIBE_REQUEST_FORMAT = r"""
         hub.log.debug(f"Could not describe {{ function.hardcoded.resource }} {ret['comment']}")
         return {}
 
+    # TODO: The parameters of the describe() output should be the same as the present() input parameters.
     for {{ function.hardcoded.resource }} in ret["ret"]["{{ function.hardcoded.list_item }}"]:
         # Including fields to match the 'present' function parameters
         # TODO convert the dictionary values from string to object by removing the quotes.
