@@ -21,12 +21,12 @@ async def update_tags(
         new_tags: list of new tags
 
     Returns:
-        {"result": True|False, "comment": "A message", "ret": None}
+        {"result": True|False, "comment": A message Tuple, "ret": None}
 
     """
     tags_to_add = []
     tags_to_remove = []
-    old_tags_map = {tag.get("Key"): tag for tag in old_tags}
+    old_tags_map = {tag.get("Key"): tag for tag in old_tags or []}
     tags_result = copy.deepcopy(old_tags_map)
     if new_tags is not None:
         for tag in new_tags:
@@ -38,7 +38,7 @@ async def update_tags(
             else:
                 tags_to_add.append(tag)
         tags_to_remove = [{"Key": tag.get("Key")} for tag in old_tags_map.values()]
-    result = dict(comment="", result=True, ret=None)
+    result = dict(comment=(), result=True, ret=None)
     if (not tags_to_remove) and (not tags_to_add):
         return result
     if tags_to_remove:
@@ -61,5 +61,5 @@ async def update_tags(
                 result["result"] = False
                 return result
     result["ret"] = {"tags": list(tags_result.values()) + tags_to_add}
-    result["comment"] = f"Update tags: Add [{tags_to_add}] Remove [{tags_to_remove}]"
+    result["comment"] = (f"Update tags: Add [{tags_to_add}] Remove [{tags_to_remove}]",)
     return result
