@@ -9,6 +9,14 @@ def would_create_comment(hub, resource_type: str, name: str) -> Tuple:
     return (f"Would create {resource_type} '{name}'",)
 
 
+def update_comment(hub, resource_type: str, name: str) -> Tuple:
+    return (f"Updated {resource_type} '{name}'",)
+
+
+def would_update_comment(hub, resource_type: str, name: str) -> Tuple:
+    return (f"Would update {resource_type} '{name}'",)
+
+
 def delete_comment(hub, resource_type: str, name: str) -> Tuple:
     return (f"Deleted {resource_type} '{name}'",)
 
