@@ -92,6 +92,12 @@ def convert_raw_subnet_to_present(
             "AvailabilityZone": "availability_zone",
             "OutpostArn": "outpost_arn",
             "MapPublicIpOnLaunch": "map_public_ip_on_launch",
+            "AssignIpv6AddressOnCreation": "assign_ipv6_address_on_creation",
+            "MapCustomerOwnedIpOnLaunch": "map_customer_owned_ip_on_launch",
+            "CustomerOwnedIpv4Pool": "customer_owned_ipv4_pool",
+            "EnableDns64": "enable_dns_64",
+            "PrivateDnsNameOptionsOnLaunch": "private_dns_name_options_on_launch",
+            "EnableLniAtDeviceIndex": "enable_lni_at_device_index",
             "Tags": "tags",
         }
     )
@@ -273,12 +279,13 @@ def convert_raw_tg_vpc_attachment(
     return translated_resource
 
 
-def convert_raw_dhcp_to_present(
-    hub, raw_resource: Dict[str, Any], idem_resource_name: str = None
+async def convert_raw_dhcp_to_present(
+    hub, ctx, raw_resource: Dict[str, Any], idem_resource_name: str = None
 ) -> Dict[str, Any]:
     resource_id = raw_resource.get("DhcpOptionsId")
     resource_parameters = OrderedDict({"Tags": "tags"})
     resource_translated = {"name": idem_resource_name, "resource_id": resource_id}
+    result = dict(comment=(), result=True, ret=None)
     for parameter_raw, parameter_present in resource_parameters.items():
         if parameter_raw in raw_resource:
             resource_translated[parameter_present] = raw_resource.get(parameter_raw)
@@ -295,7 +302,20 @@ def convert_raw_dhcp_to_present(
             }
             dhcp_configs.append(dhcp_config)
         resource_translated["dhcp_configurations"] = dhcp_configs
-    return resource_translated
+    vpc_list = []
+    vpc_ret = await hub.exec.boto3.client.ec2.describe_vpcs(ctx)
+    if not vpc_ret["result"]:
+        result["comment"] = vpc_ret["comment"]
+        result["result"] = vpc_ret["result"]
+    else:
+        for vpc in vpc_ret["ret"]["Vpcs"]:
+            if vpc["DhcpOptionsId"] == resource_id:
+                vpc_list.append(vpc["VpcId"])
+    if vpc_list:
+        resource_translated["vpc_id"] = vpc_list
+
+    result["ret"] = resource_translated
+    return result
 
 
 def convert_raw_sg_to_present(hub, security_group: Dict):
