@@ -1,4 +1,5 @@
 import re
+import time
 from typing import Any
 from typing import Dict
 from typing import Generator
@@ -31,7 +32,17 @@ async def exec_(
     :return: The result of the operation call
     """
     session: boto3.session.Session = hub.tool.boto3.session.get()
-    client = session.client(service_name=service_name, **ctx.acct)
+    client = session.client(
+        service_name=service_name,
+        region_name=ctx.acct.get("region_name"),
+        api_version=ctx.acct.get("api_version"),
+        use_ssl=ctx.acct.get("use_ssl", True),
+        endpoint_url=ctx.acct.get("endpoint_url"),
+        aws_access_key_id=ctx.acct.get("aws_access_key_id"),
+        aws_secret_access_key=ctx.acct.get("aws_secret_access_key"),
+        aws_session_token=ctx.acct.get("aws_session_token"),
+        verify=ctx.acct.get("verify"),
+    )
 
     # Don't pass kwargs that have a "None" value to the function call
     kwargs = {k: v for k, v in op_kwargs.items() if v is not None}
@@ -55,7 +66,17 @@ async def exec_(
 
 def get_client(hub, ctx, service_name: str):
     session: boto3.session.Session = hub.tool.boto3.session.get()
-    client = session.client(service_name=service_name, **ctx.acct)
+    client = session.client(
+        service_name=service_name,
+        region_name=ctx.acct.get("region_name"),
+        api_version=ctx.acct.get("api_version"),
+        use_ssl=ctx.acct.get("use_ssl", True),
+        endpoint_url=ctx.acct.get("endpoint_url"),
+        aws_access_key_id=ctx.acct.get("aws_access_key_id"),
+        aws_secret_access_key=ctx.acct.get("aws_secret_access_key"),
+        aws_session_token=ctx.acct.get("aws_session_token"),
+        verify=ctx.acct.get("verify"),
+    )
     return client
 
 
@@ -65,17 +86,19 @@ async def wait(
     service_name: str,
     waiter_name: str,
     custom_waiter=None,
+    delay: int = None,
     *wt_args,
     **wt_kwargs,
 ) -> None:
     """
-    Asynchronously wait for the named resource to be avilable
+    Asynchronously wait for the named resource to be available
 
     :param hub:
     :param ctx:
     :param service_name: The name of the service client to retrieve
     :param waiter_name: The name of the waiter to get from the service client
     :param custom_waiter: If an inbuilt waiter is not available , we can provide custom waiter for the service client
+    :param delay: The delay in seconds before starting the waiter
     :param wt_args: Args to pass to the wait function
     :param wt_kwargs: kwargs to pass to the wait function
     """
@@ -96,6 +119,11 @@ async def wait(
 
         waiter = client.get_waiter(waiter_name)
 
+    if delay is not None:
+        # There might be some delay for the resource to start updating/deleting after the api call
+        hub.log.debug(f"Waiting '{delay}' seconds, before starting the waiter")
+        time.sleep(delay)
+
     await hub.pop.loop.wrap(waiter.wait, *wt_args, **wt_kwargs)
 
 
@@ -109,7 +137,17 @@ def search(hub, ctx, service_name: str, collection: str, jmes_path: str = "*[]")
     :return:
     """
     session: boto3.session.Session = hub.tool.boto3.session.get()
-    client = session.client(service_name=service_name, **ctx.acct)
+    client = session.client(
+        service_name=service_name,
+        region_name=ctx.acct.get("region_name"),
+        api_version=ctx.acct.get("api_version"),
+        use_ssl=ctx.acct.get("use_ssl", True),
+        endpoint_url=ctx.acct.get("endpoint_url"),
+        aws_access_key_id=ctx.acct.get("aws_access_key_id"),
+        aws_secret_access_key=ctx.acct.get("aws_secret_access_key"),
+        aws_session_token=ctx.acct.get("aws_session_token"),
+        verify=ctx.acct.get("verify"),
+    )
 
     # Find a paginator that can describe this collection
     for operation in client.meta.method_to_api_mapping:
